import { Component, Element } from '@stencil/core';
import { setCurrencyCode, loadCldr, setCulture } from "@syncfusion/ej2-base";
import { NumericTextBox } from "@syncfusion/ej2-inputs";
import { DropDownList } from "@syncfusion/ej2-dropdowns";

import { cldrCurrencies } from '../../global/currencies';
import { cldrNumberingSystems } from '../../global/numberingSystems';
import { cldrNumbers } from '../../global/numbers';

@Component({
  tag: 'app-root',
  styleUrl: 'app-root.css',
  shadow: false,
})
export class AppRoot {
  @Element() el: HTMLElement;

  componentWillLoad() {
    loadCldr(cldrCurrencies, cldrNumberingSystems, cldrNumbers);
    setCulture('en');
    setCurrencyCode('EUR');
  }

  componentDidLoad() {
    new DropDownList({
      change: (args) => {
        setCurrencyCode(args.value as string);
      }
    }, this.el.querySelector('#uiCurrency') as HTMLSelectElement)

    new NumericTextBox({
      value: 2345.67,
      format: 'c2',
    }, this.el.querySelector('#noCurrency') as HTMLInputElement);

    new NumericTextBox({
      value: 2345.67,
      format: 'c2',
      currency: 'AUD',
    }, this.el.querySelector('#audCurrency') as HTMLInputElement);

    new NumericTextBox({
      value: 2345.67,
      format: 'c2',
      currency: 'JPY',
    }, this.el.querySelector('#jpyCurrency') as HTMLInputElement);

    new NumericTextBox({
      value: 2345.67,
      format: 'c2',
      currency: 'EUR',
    }, this.el.querySelector('#eurCurrency') as HTMLInputElement);
  }

  render() {
    return (
      <div>
        <header>
          <h1>Currency code issue</h1>
        </header>

        <main>
          <p class="note">Application configured for 'en' culture</p>
          <p>
            <label htmlFor="uiCurrency">UI currency code:</label>
            <select id="uiCurrency">
              <option value="EUR" selected>Euro - EUR</option>
              <option value="GBP">Sterling - GBP</option>
              <option value="JPY">Japanese Yen - JPY</option>
              <option value="USD">US Dollar - USD</option>
              <option value="AUD">Australian Dollar - AUD</option>
              <option value="ZAR">South African Rand - ZAR</option>
            </select>
          </p>

          <fieldset>
            <legend>Should follow UI currency</legend>
            <p>
              <label htmlFor="noCurrency">UI currency</label>
              <input type="tel" id="noCurrency" />
            </p>
          </fieldset>



          <fieldset>
            <legend>Should honor the instance currency</legend>
            <p class="note">(Select a different 'UI Currecy code' above to demonstrate the issue)</p>
            <p>
              <label htmlFor="audCurrency">Australian Dollar</label>
              <input type="tel" id="audCurrency" />
            </p>

            <p>
              <label htmlFor="jpyCurrency">Japanese Yen</label>
              <input type="tel" id="jpyCurrency" />
            </p>

            <p>
              <label htmlFor="eurCurrency">Euro</label>
              <input type="tel" id="eurCurrency" />
            </p>
          </fieldset>



        </main>
      </div>
    );
  }
}
